#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colour
version:              2.3.7
visibility:           public
id:                   colour-2.3.7-52DaKKnDbdRf7CUEo3dC5
key:                  colour-2.3.7-52DaKKnDbdRf7CUEo3dC5
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  e0e8fe1027e8af0eaf668705a994c746
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.Ok Data.Colour.RGBSpace
    Data.Colour.RGBSpace.HSL Data.Colour.RGBSpace.HSV Data.Colour.SRGB
    Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colour-2.3.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colour-2.3.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colour-2.3.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.7-52DaKKnDbdRf7CUEo3dC5
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

